@@ -87,7 +87,7 @@
 #' \item{lambda, alpha}{lambda and alpha used, respectively.}
 #' \item{formula}{model formula used in the fit.}
 #' \item{means}{vector of column means of the X matrix. Subsequent survival curves are adjusted to this value.}
-#' \item{}{See \code{\link[stats]{model.frame}} for \code{assign}, \code{xlevels}, \code{contrasts} and \code{terms}.}
+#' \item{assign, xlevels, terms}{See \code{\link[stats]{model.frame}} for \code{assign}, \code{xlevels}, \code{contrasts} and \code{terms}.}
 #'
 #' @seealso
 #' \code{\link[survival]{coxph}}, \code{\link[pcoxtime]{pcoxtimecv}}
@@ -231,11 +231,31 @@ pcoxtime <- function(formula, data, alpha = 1, lambda = 1
 
 	# Some posthocs
 	n.risk <- sort(unique(drop(model_est[["n.risk"]])), decreasing = TRUE)
-	temp_df <- data.frame(temp_df[order(temp_df[, timevarlabel]), ])
-	temp_df$censorvar <- 1 - temp_df[, eventvarlabel]
-	n.event <- as.vector(t(aggregate(as.formula(paste0(eventvarlabel, "~", timevarlabel)), temp_df, FUN = sum)[2]))
-	n.censor <- as.vector(t(aggregate(as.formula(paste0("censorvar", "~", timevarlabel)), temp_df, FUN = sum)[2]))
-	time <- unique(temp_df[, timevarlabel])
+
+	## 2022 Jan 01 (Sat): breaks for y~x
+#	temp_df <- data.frame(temp_df[order(temp_df[, timevarlabel]), ])
+#	temp_df$censorvar <- 1 - temp_df[, eventvarlabel]
+	
+#	n.event <- as.vector(t(aggregate(as.formula(paste0(eventvarlabel, "~", timevarlabel)), temp_df, FUN = sum)[2]))
+#	n.censor <- as.vector(t(aggregate(as.formula(paste0("censorvar", "~", timevarlabel)), temp_df, FUN = sum)[2]))
+#	time <- unique(temp_df[, timevarlabel])
+	
+	## 2022 Jan 01 (Sat): FIX for breaks for y~x
+
+	if (NCOL(temp_df)==2) {
+		temp_df <- data.frame(temp_df[order(temp_df[, 1]), ])
+		temp_df$censorvar <- 1 - temp_df[, 2]
+		n.event <- as.vector(t(aggregate(temp_df[,2]~temp_df[,1], FUN = sum)[2]))
+		n.censor <- as.vector(t(aggregate(temp_df[,3]~temp_df[,1], FUN = sum)[2]))
+		time <- unique(temp_df[, 1])
+	} else {
+		temp_df <- data.frame(temp_df[order(temp_df[, 2]), ])
+		temp_df$censorvar <- 1 - temp_df[, 3]
+		n.event <- as.vector(t(aggregate(temp_df[,3]~temp_df[,2], FUN = sum)[2]))
+		n.censor <- as.vector(t(aggregate(temp_df[,4]~temp_df[,2], FUN = sum)[2]))
+		time <- unique(temp_df[, 2])
+		
+	}
 	n <- length(times)
 	
 	result <- list(coef = beta_hat
